# TutCatalog5

A simple viewer and editor for `info.tc` files that contains tutorial information.

## History

| Program | Programming Language | Development |
|---|---|---|
| tutcatalog5 | C++ / Python |  2024 |
| tutcatalog4 | C++ / Python |  2022 |
| tutcatalogpy3 | Python | 2022 |
| tutcatalogpy2 | Python | 2021 |
| tutcatalogpy | Python | 2020 |
| tucatalog3 | C++ / Python | 2017 |
| tutcatalog | C++ / Python | 2016 |
